==> kubernetes-model-resource-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimSpecFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ResourceClaimSpecFluent<A extends ResourceClaimSpecFluent<A>> extends Fluent<A>{
  public String getAllocationMode();
  public A withAllocationMode(String allocationMode);
  public Boolean hasAllocationMode();
  
  /**
   * This method has been deprecated, please use method buildParametersRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceClaimParametersReference getParametersRef();
  public ResourceClaimParametersReference buildParametersRef();
  public A withParametersRef(ResourceClaimParametersReference parametersRef);
  public Boolean hasParametersRef();
  public A withNewParametersRef(String apiGroup,String kind,String name);
  public ResourceClaimSpecFluent.ParametersRefNested<A> withNewParametersRef();
  public ResourceClaimSpecFluent.ParametersRefNested<A> withNewParametersRefLike(ResourceClaimParametersReference item);
  public ResourceClaimSpecFluent.ParametersRefNested<A> editParametersRef();
  public ResourceClaimSpecFluent.ParametersRefNested<A> editOrNewParametersRef();
  public ResourceClaimSpecFluent.ParametersRefNested<A> editOrNewParametersRefLike(ResourceClaimParametersReference item);
  public String getResourceClassName();
  public A withResourceClassName(String resourceClassName);
  public Boolean hasResourceClassName();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParametersRefNested<N> extends Nested<N>,ResourceClaimParametersReferenceFluent<ResourceClaimSpecFluent.ParametersRefNested<N>>{
    public N and();
    public N endParametersRef();
    
  }
  
}

==> kubernetes-model-resource-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimSpecFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimSpecFluent<A extends ResourceClaimSpecFluent<A>> extends Fluent<A>{
  public String getAllocationMode();
  public A withAllocationMode(String allocationMode);
  public Boolean hasAllocationMode();
  
  /**
   * This method has been deprecated, please use method buildParametersRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceClaimParametersReference getParametersRef();
  public ResourceClaimParametersReference buildParametersRef();
  public A withParametersRef(ResourceClaimParametersReference parametersRef);
  public Boolean hasParametersRef();
  public A withNewParametersRef(String apiGroup,String kind,String name);
  public ResourceClaimSpecFluent.ParametersRefNested<A> withNewParametersRef();
  public ResourceClaimSpecFluent.ParametersRefNested<A> withNewParametersRefLike(ResourceClaimParametersReference item);
  public ResourceClaimSpecFluent.ParametersRefNested<A> editParametersRef();
  public ResourceClaimSpecFluent.ParametersRefNested<A> editOrNewParametersRef();
  public ResourceClaimSpecFluent.ParametersRefNested<A> editOrNewParametersRefLike(ResourceClaimParametersReference item);
  public String getResourceClassName();
  public A withResourceClassName(String resourceClassName);
  public Boolean hasResourceClassName();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParametersRefNested<N> extends Nested<N>,ResourceClaimParametersReferenceFluent<ResourceClaimSpecFluent.ParametersRefNested<N>>{
    public N and();
    public N endParametersRef();
    
  }
  
}
